#!/usr/bin/env bash

stats_raw=`curl --connect-timeout 2 --max-time $API_TIMEOUT --silent --noproxy '*' http://127.0.0.1:$MINER_API_PORT`
if [[ $? -ne 0 || -z $stats_raw ]]; then
   echo -e "${YELLOW}Failed to read stats from http://127.0.0.1:$MINER_API_PORT"
else
   local temp=$(jq "[.temp$nvidia_indexes_array]" <<< $gpu_stats)
   local fan=$(jq "[.fan$nvidia_indexes_array]" <<< $gpu_stats)
   local ver=`echo $stats_raw | jq -c -r ".version"`
   local bus_numbers=$(echo $stats_raw | jq -r ".devices[].bus_id" |  jq -sc .)
   local algo=$ONEZEROMINER_ALGO
   local ac=`echo $stats_raw | jq -c -r ".algos[0].total_accepted_shares"`
   local inv=`echo $stats_raw | jq -c -r ".algos[0].total_rejected_shares"` 
   local uptime=`echo $stats_raw | jq -c -r ".uptime_seconds"`


   units="hs"
   hs=`echo $stats_raw | jq -r ".algos[0].total_hashrate"`
   khs=$(jq -n --argjson hs "$hs" '$hs / 1000')
  
   # DNX only
   stats=$(jq --arg total_khs "$khs" \
           --arg ac "$ac" --arg inv "$inv" \
           --arg algo "$algo" \
           --arg ver "$ver" --arg uptime "$uptime" \
           --argjson fan "$fan" --argjson temp "$temp" \
           --argjson bus_numbers "$bus_numbers" \
           --arg units "$units" \
           '{$ver, $uptime, $total_khs, hs: .algos[0].hashrates, hs_units: $units,  $temp, $fan, $algo, ar: [$ac, $inv], $bus_numbers}' <<< "$stats_raw")

   # DNX+ZIL
   if [[ $(echo $stats_raw | jq -r '.num_algos') -gt 1 ]]; then
     total_khs2=`echo $stats_raw | jq -r ".algos[1].total_hashrate"`
     total_khs2=$((total_khs2 / 1000))
     units2="hs"
     ac2=`echo $stats_raw | jq -c -r ".algos[1].total_accepted_shares"`
     inv2=`echo $stats_raw | jq -c -r ".algos[1].total_rejected_shares"`
     stats2=$(jq --arg total_khs2 "$total_khs2" \
           --arg ac2 "$ac2" --arg inv2 "$inv2" \
           --arg algo2 "ethash" \
           --arg units2 "$units2" \
           --argjson bus_numbers2 "$bus_numbers" \
           '{$total_khs2, hs2: [.algos[1].hashrates[]/1000], $units2, $algo2, ar2: [$ac2, $inv2], $bus_numbers2}' <<< "$stats_raw")
     stats=$(jq -s '.[0] * .[1]' <<< "$stats $stats2")
   fi
fi

[[ -z $khs ]] && khs=0
[[ -z $stats ]] && stats="null"
